@@ -72,6 +72,10 @@ plot.Rcpp_Trace <- function(x, what=c("Mutation", "Selection", "MixtureProbabili
   {
     plotExpressionTrace(x, geneIndex)
   }
+  if(what[1] == "AcceptanceRatio")
+  {
+    plotCodonSpecificHyperParameters(x, what = what[1])
+  }
 
 
 }
@@ -197,22 +201,22 @@ plotCodonSpecificParameters <- function(trace, mixture, type="Mutation", main="M
 # Called from Plot Trace Object (plot for trace)
 # NOT EXPOSED
 # 
-#' Plot Codon Specific Hyper Parameter
+# Plot Codon Specific Hyper Parameter
 #' @param trace An Rcpp trace object initialized with \code{initializeTraceObject}.
-#'
-#' @param mixture The mixture for which to plot values.
-#'
-#' @param type A string containing one of the following to graph: \code{Random, LoglikelihoodRatio, currLoglikelihood, propLoglikelihood, currLoglikelihoodAdjusted, propLoglikelihoodAdjusted}. 
-#'
+#' 
+#' @param what A string containing one of the following to graph: \code{Random, LoglikelihoodRatio, currLoglikelihood, propLoglikelihood, currLoglikelihoodAdjusted, propLoglikelihoodAdjusted}.
+#' 
+#' @param mixture Mixture category to plot
+#' 
 #' @param main The title of the plot.
-#'
-#' @param PA A logical value determining if the Parameter was PA or not.
-#'
+#' 
+#' @param PA A logical value determining if the Parameter was PA or not. Default is True
+#' 
 #' @return This function has no return value.
 #' 
 #' @description Plots a codon-specific set of traces, specified with the \code{type} parameter.
-#'
-plotCodonSpecificHyperParameters <- function(trace, mixture, type="RandomNumber", main="Random Number Parameter Traces", PA=TRUE)
+
+plotCodonSpecificHyperParameters <- function(trace, what="RandomNumber", mixture=1, main="Random Number Parameter Traces", PA=TRUE)
 {
   opar <- par(no.readonly = T) 
   
@@ -242,22 +246,22 @@ plotCodonSpecificHyperParameters <- function(trace, mixture, type="RandomNumber"
     if(length(codons) == 0) next
  	cur.trace <- vector("list", length(codons))
     
- 	  if(type == "RandomNumber"){
+ 	  if(what == "RandomNumber"){
  	    ylab <- expression("Random Number")
  	    paramType <- 0
- 	  }else if (type == "AcceptanceRatio"){
+ 	  }else if (what == "AcceptanceRatio"){
  	    ylab <- expression("Acceptance Ratio")
  	    paramType <- 1
- 	  }else if (type == "CurrentLogLikelihood"){
+ 	  }else if (what == "CurrentLogLikelihood"){
  	    ylab <- expression("Current Log Likelihood")
  	    paramType <- 2
- 	  }else if (type == "ProposedLogLikelihood"){
+ 	  }else if (what == "ProposedLogLikelihood"){
  	    ylab <- expression("Proposed Log Likelihood")
  	    paramType <- 3
- 	  }else if (type == "CurrentLogLikelihoodAdjusted"){
+ 	  }else if (what == "CurrentLogLikelihoodAdjusted"){
  	    ylab <- expression("Adjusted Current Log Likelihood")
  	    paramType <- 4
- 	  }else if (type == "ProposedLogLikelihoodAdjusted"){
+ 	  }else if (what == "ProposedLogLikelihoodAdjusted"){
  	    ylab <- expression("Adjusted Proposed Log Likelihood")
  	    paramType <- 5
  	  }else{
@@ -266,7 +270,12 @@ plotCodonSpecificHyperParameters <- function(trace, mixture, type="RandomNumber"
     
     for(i in 1:length(codons))
     { 
-        cur.trace[[i]] <- trace$getCodonSpecificHyperParameterTraceByMixtureElementForCodon(mixture, codons[i], paramType)
+        if(paramType == 1){
+            cur.trace[[i]] <- trace$getCodonSpecificAcceptanceRateTraceForAA(codons[i])
+        }
+        else{
+            cur.trace[[i]] <- trace$getCodonSpecificHyperParameterTraceByMixtureElementForCodon(mixture, codons[i], paramType)
+        }
     }
   
     
